****************************************
Tools to help with the instrument design
****************************************
In this section, we introduce tools for instrument designers. If you just want
to run a simulation for a mission that's already modeled in MARXS, skip this
section.

We welcome contributions to help with the design of any type of
instrument. Currently, Rowland spectrometers have the most detailed tools to
place gratings and detectors in a right position. Another aspect of this
package is to assess the robustness of any design. To that end, ray-trace
simulations can be used to simulate a misaligned version of any instrument to
see how performance degrades.



.. toctree::
   :maxdepth: 2

   design/rowland
   design/tolerancing
   design/uncertainties

